function [Diag,q,datos_vector,F_tot,rho]=Lippmann_schwinger_driver(N,k,...
    lente,NN,sigma,HH)

%%%% Example to run this code
%%%% Lippmann_schwinger_driver(300,2*pi*20,'file_name',NN,sigma);

    [Diag,q,datos_vector,F_tot,rho]=Type_Helmholtz_2D(N,k,...
        lente,NN,sigma,HH);
    tic %P: Comienzo a medir el tiempo total

end

function [Diag,q,datos_vector,F_tot,rho]=Type_Helmholtz_2D(N,k,lente,...
    NN,sigma,HH)

    'Obtaining q function';
    tic
    f=2*pi*k;
 
    q = q_2D_limpio(lente,N,median(f));
    fga=contains(lente,'fga');
    if    fga==1
        q=filtra_q(q,NN,sigma);
    end
    toc
    %   Here we obtain the right hand side corresponding to an incoming plane
    %   wave towards +x.
    %  [B,U]=RHS_Helmholtz_2D_Incoming(N,k,q);
    M=20;
    fVar=2*pi*k;
    
    Diag_foco=diagrama_foco(M,HH);

    x0=-0.1; %Posicin foco x
    y0=.5;  %Posicin foco y
    
    lenF=length(fVar);
    rho=zeros(N,N,lenF);
    F_tot=zeros(N,N,lenF);
    datos_vector=zeros(10,lenF); %10 variables almacenadas
    Diag=zeros(lenF,30*M*2);
    
    for count=1:lenF
        [B,U]=RHS_Helmholtz_2D_Incoming(N,fVar(count),q,Diag_foco,M,x0,y0);
        %% Se crean los coeficientes para la convolucin con la funcin de Green
        'Setting up coefficients'
        tic
        [GG,FX,FY]=Volume_density_setup_2D('Helmholtz',fVar(count),N);
        T_setup=toc


        flag_solver=2;
        if (flag_solver==1)|(flag_solver==0)
            'Start GMRES'
            tic
            tol = 1e-10;  maxit = 1000;
            [x1,FLAG,RELRES,ITER] =  gmres(@(x)Matrix_multip_Helmholtz_2D...
                (x,GG,FX,FY,q,N,fVar(count)),B,[],tol,maxit);
            T_itertot=toc;
            RELRES;
            ITER
            FLAG;
        end

        if (flag_solver==2)|(flag_solver==0)
            'Start BICGSTAB'
            tic
            tol = 1e-10;  maxit = 5000;
            [x1,FLAG,RELRES,ITER] = bicgstab(@(x)Matrix_multip_Helmholtz_2D...
                (x,GG,FX,FY,q,N,fVar(count)),B,tol,maxit);
            RELRES;
            ITER
            FLAG;
            T_itertot=toc;
        end

        rho(:,:,count)=reshape(x1,N,N);
        
        flag1=2;
        [Field,Dx,Dy]=Volume_density_fast_2D(GG,FX,FY,rho(:,:,count),...
            fVar(count),N,flag1);
        Field=Field(:);
        %     Error_rel_norm=norm(Field-U)/norm(U);
%         Error_abs=max(abs((Field-U)./U));
%         indices=(1:length(x1));

        Field_plot=reshape(Field,N,N);
        U_plot=reshape(U,N,N);
        F_tot(:,:,count)=U_plot+Field_plot;

%{            
        if fga==0 
            
            
            x=linspace(0,1,N+1);
            x=x(1:end-1);
            y=x;
            [X,Y]=meshgrid(x,y);
            
            sum=sum+1;
            hCampLen(sum)=figure;
            
            subplot(1,2,1)
            pcolor(X,Y,abs(F_tot))
            shading interp
%             xlabel ('N','FontSize',12,'FontWeight','bold','Color','r')
%             title(['Campo elctrico a con k= ' num2str(k(count))] )
            axis square
            
            subplot(1,2,2)
            pcolor(X,Y,angle(F_tot))
            shading interp
%             xlabel ('N','FontSize',12,'FontWeight','bold','Color','r')
%             title(['k=' num2str(k(count))] )
            axis square
            
            sum=sum+1;
            hCampLen(sum)=figure;

            pcolor(X,Y,abs(rho(:,:,count)))         
            grid           
            shading interp           
            xlabel ('N','FontSize',12,'FontWeight','bold','Color','r')            
            title(['Diseo lente para k= ' num2str(k(count))] )   
      
        end
    %}
        Ttotal= toc %P: Finalizo de medir el tiempo total 
        
        M2=30*M;
        R_max=1000;

        Diag(count,:)=diagrama_2D_v4(rho(:,:,count),N,M2,fVar(count),x0,y0,Diag_foco,R_max);

        datos_vector(1,count)=N;
        datos_vector(2,count)=ITER;
        datos_vector(3,count)=T_itertot;    
        datos_vector(4,count)=T_setup;
        datos_vector(5,count)=FLAG;
        datos_vector(6,count)=fVar(count);
        datos_vector(7,count)=maxit;
        datos_vector(8,count)=RELRES;
        datos_vector(9,count)=tol;
        datos_vector(10,count)=Ttotal;  %Tiempo total        
        
    end
    
end