function disenyaLente(lente,k,N)
    %% Parametros de entrada iniciales
        % lente: indica la lente a utilizar: placnvex, heterog, placnvexfres
        %   para filtrado gaussiano aadir prefijo fga-
        %   para modificar foco, en el parmetro lente: foco
        %
        % k: frecuencia para la que se disea la lente
        %
        % N: puntos de muestra
        % 
        % Ejemplo: disenyaLente('placnvex',20,300);
    
    M=600; %Obtenido de Lippmann_schinger_driver M1*M2 y se considera valor
           %por defecto

    phiVector=linspace(-pi,pi,2*M+1);
    phiVector=phiVector(1:end-1); %Vector para la representascin entre -pi y pi
    HH=4; %Valor por defecto para el foco
    % Se identifica el tipo de lente que se va a analizar en cada
    % condicin
    
    if strcmpi('placnvex',lente) || strcmpi('heterog',lente)
    %% Lente plano-convexa y heterogenea
        cabeceraPlHe= {'Nombre del archivo de guardado'};
        tituloPlHe= 'Simulacin de lente';
        respDef={'Lente'};
        respPlHe= inputdlg(cabeceraPlHe,tituloPlHe,...
            [1 45],respDef);
        nomArchivo= char(respPlHe);
        
        datTit=k;
        
        [diagLog,q,datos_vector,F_tot,rho]=  ...
            Lippmann_schwinger_driver(N,k,lente,0,1,HH);
        sum=0;
        
        [hCampLen,sum]= dibujaLente(N,datTit,F_tot,rho,sum);

        hCampLen=plotDiag(M,HH,phiVector,diagLog,sum,hCampLen);

        save(nomArchivo,'rho','datos_vector','F_tot','diagLog','q')
        nomArchivo=strcat(nomArchivo, '.fig');
        savefig(hCampLen,nomArchivo)
        
        
    elseif strcmpi('placnvexfres',lente)
    %% Lente plano-convexa de Fresnel 

        respFrec= pregFrec;
        nomArchivo= char(respFrec(3,1));

        if strcmpi('N',respFrec(1,1))
            [diagLog,q,datos_vector,F_tot,rho]= Lippmann_schwinger_driver(N,k,...
            lente,0,1,HH);
            sum=0;
            datTit=k;
            
            [hCampLen,sum]= dibujaLente(N,datTit,F_tot,rho,sum);
            hCampLen= plotDiag(M,HH,phiVector,diagLog,sum,hCampLen);
            
            save(nomArchivo,'rho','datos_vector','F_tot','diagLog','q')
            nomArchivo= strcat(nomArchivo, '.fig');
            savefig(hCampLen,nomArchivo)       
 
        else
            %% Anlisis del ancho de banda
            numText= cell2mat(respFrec(2,1));
            BW= str2double(numText);
            kVar= k-BW:1:k+BW; %
            
            [diagLog,q,datos_vector,F_tot,rho]= Lippmann_schwinger_driver...
                (N,kVar,lente,0,1,HH);
            hCampLen= compFrecs(N,kVar,diagLog,phiVector,F_tot,rho);
            
            save(nomArchivo,'rho','datos_vector','F_tot','diagLog','q')
            nomArchivo= strcat(nomArchivo, '.fig');
            savefig(hCampLen,nomArchivo)
            
            close(hCampLen(1:end-2))
            abrirArc(nomArchivo)
            
        end

    %% Lentes con filtro gaussiano
    elseif contains(lente,'fga')==1

        respFil= pregFil;
        NNVar= cell2mat(respFil(1,1));
        NNVar= sort(str2num(NNVar));
        sigmaVar= cell2mat (respFil(2,1));
        sigmaVar= sort(str2num(sigmaVar));

        nomArchivo=char(respFil(3,1));   
        
        lenPun=length(NNVar);
        lenSig=length(sigmaVar);
        
        if lenPun==1 && lenSig==1
            %Anlisis para puntos y sigma fijos
            [diagLog,q,datos_vector,F_tot,rho]=Lippmann_schwinger_driver...
                (N,k,lente,NNVar,sigmaVar,HH);
            
            datTit=[k,NNVar,sigmaVar];
            sum=0;
            [hCampLen,sum]=dibujaLente(N,datTit,F_tot,rho,sum);
            
            lenteOriginal(lente,N,k)
            
            sum=sum+1;
            hCampLen(sum)=figure;
            surf(q)
            shading interp
            title(['Lente filtrada: NN= ' num2str(NNVar)...
                ' \sigma= ' num2str(sigmaVar)])
            
            hCampLen= plotDiag(M,HH,phiVector, diagLog, sum, hCampLen);
            
            save(nomArchivo,'rho','datos_vector','F_tot','diagLog','q')
            nomArchivo=strcat(nomArchivo, '.fig');
            savefig(hCampLen,nomArchivo)

% {
        else
            %% Anlisis para sigma variable y puntos variables
  
            diagLog= zeros(lenPun, M*2, lenSig);
            q= zeros(N,N,lenPun,lenSig);
            F_tot= zeros(N,N,lenPun,lenSig);
            rho= zeros(N,N,lenPun,lenSig);
            lenteOriginal(lente, N, k) %Lente sin filtrar 
            sum= 0;
            numGrafs= lenPun*lenSig*2+lenPun;
            hCampLen= gobjects(numGrafs, 1);

            for countP= 1:lenPun
                for countS= 1:lenSig
                    [diagLog(countP,:,countS), q(:,:,countP,countS),...
                        datos_vector(:,countP,countS),F_tot(:,:,countP,countS),...
                        rho(:,:,countP,countS)]= Lippmann_schwinger_driver...
                        (N,k,lente,NNVar(countP),sigmaVar(countS),HH);
                    
                    datTit=[k,NNVar(countP),sigmaVar(countS)];
                    [hCampLen,sum]=dibujaLente(N,datTit,F_tot(:,:,countP,countS),...
                        rho(:,:,countP,countS),sum,hCampLen);
                    
                    sum= sum+1;
                    hCampLen(sum) =figure;
                    surf(q(:,:,countP,countS));
                    shading interp
                    title(['Lente filtrada: NN= ' num2str(NNVar(countP)) ...
                        ' \sigma= ' num2str(sigmaVar(countS))])
                end
            end
           

            hCampLen= compPunSigma(NNVar,sigmaVar,diagLog,phiVector,sum,hCampLen);
            
            save(nomArchivo,'rho','datos_vector','F_tot','diagLog','q')
            nomArchivo=strcat(nomArchivo, '.fig');
            savefig(hCampLen,nomArchivo);
            
            close(hCampLen(1:end-1))
            abrirArc(nomArchivo)
        end
%}
    elseif strcmpi('foco',lente)
        %% Modificacin del foco
        
        cabeceraFoco= {'Valores para HH (Varia la directividad del foco)',...
            'Nombre del archivo de guardado'};
        tituloFoco= 'Simulacin de la lente';
        respFoco= inputdlg(cabeceraFoco,tituloFoco,...
            [1 45;1 45]);
        %Obtencin de datos del cuadro de dilogo
        nomArchivo= char(respFoco(2,1));
        varHH= cell2mat (respFoco(1,1));
        varHH= sort(str2num(varHH));
        lenHH= length(varHH);
        
        % Inicializacin de variables
        maxDiagTot= zeros(1,lenHH);
        legCompHH= cell(zeros(1,lenHH));
        diagLog= zeros(lenHH,M*2);
        F_tot=zeros(N,N,lenHH);
        rho=zeros(N,N,lenHH);
        sum=0;
        
        hFoco= gobjects(length(lenHH)*2+1,1);
        % Se ejecuta el algoritmo para cada valor de HH
        for countHH=1:lenHH
            [diagLog(countHH,:),q,datos_vector(:,countHH),F_tot(:,:,countHH),...
                rho(:,:,countHH)]= Lippmann_schwinger_driver(N,k,...
                'placnvex',0,1,varHH(countHH));
            
            datTit=[k varHH(countHH)];
            [hFoco,sum]= dibujaLente(N,datTit,F_tot(:,:,countHH),...
                rho(:,:,countHH),sum,hFoco);
            
            maxDiag= max(diagLog(countHH,:));
            maxDiagTot(countHH)= maxDiag;
            legnd1= ['HH= ' num2str(varHH(countHH))...
                ' Max= ' num2str(maxDiag)];%Aade leyenda de cada punto
            legCompHH(countHH)= cellstr(legnd1); %Array con todas las leyendas

        end
        
        sum=sum+1;
        hFoco(sum)=figure;
        plot(varHH,maxDiagTot,'-*');
        xlabel('HH','FontSize',12,'FontWeight','bold');
        xlim([min(varHH)-1 max(varHH)+1])
        ylabel('Directividad (dB)','FontSize',12,'FontWeight','bold')
        MaxAx= gca;
        MaxAx.FontSize= 12;
        MaxAx.FontWeight= 'bold';
        
        sum=sum+1;
        hFoco(sum)=figure;
        plot(phiVector,diagLog)
        title('Diagramas de radiacin para diferentes focos ')
        legend(legCompHH,'Location','best');

        xlabel('\phi (rad)', 'FontSize',12,'FontWeight','bold')
        xlim([-3.5 3.5])
        ylabel('Directividad (dB)', 'FontSize',12,'FontWeight','bold')
        DmaxAx= gca;
        DmaxAx.FontSize= 12;
        DmaxAx.FontWeight='bold';

        save(nomArchivo,'rho','datos_vector','F_tot','diagLog','q')
        nomArchivo= strcat(nomArchivo, '.fig');
        savefig(hFoco,nomArchivo)
        close(hFoco(1:end-2))
        abrirArc(nomArchivo)
    else
            'Lente no reconocida'
    end
end
%% Figura con el diagrama de radiacin
function hCampLen=plotDiag(M,HH,phiVector, diagLog, sum, hCampLen)
    diagFoco= diagrama_foco(M,HH);
    diagFoco=10*log10(abs(diagFoco));
    sum= sum+1;
    hCampLen(sum)=figure;
    
    plot(phiVector, diagLog, 'r', 'LineWidth', 0.7)
    hold on
    plot(phiVector, diagFoco, 'b', 'LineWidth', 0.7)
    hold off
%     maximoDiag= max(dia   gLog);
    legend('Lente' ,'Foco');
    xlabel('\phi (rad)', 'FontSize',12,'FontWeight','bold')
    ylabel('Directividad (dB)', 'FontSize',12,'FontWeight','bold')
    xlim([-3.5 3.5])
    DiagMaxAx =  gca;
    DiagMaxAx.FontSize= 12;
    DiagMaxAx.FontWeight='bold';

end

%% Cuadro de dilogo para filtro gaussiano
function respFrec=pregFrec
    cabeceraFrec= {'Anlisis en frecuencia? (S/N)','Ancho de banda:',...
        'Nombre del archivo'};
    tituloFrec= 'Anlisis frecuencial';
    respDef={'N', '0','Lente_Fresnel'};
    respFrec= inputdlg(cabeceraFrec,tituloFrec,...
        [1 45;1 45;1 45],respDef);
end

%% Cuadro de dilogo para el filtro gaussiano
function respFil=pregFil
    
    cabeceraFil= {'NN:' '\sigma:' 'Nombre de archivo:'};
    tituloFil= 'Filtro gaussiano';
    options.Interpreter='tex';
    defaultans= {'0' '1' 'Filtro'};
    respFil= inputdlg(cabeceraFil,tituloFil,...
        [1 40; 1 40;1 40],defaultans,options);

end

%% Lente original antes de filtrar
function lenteOriginal(lente,N,k)

    qOriginal= q_2D_limpio(lente,N,2*pi*k);
    figure
    surf(qOriginal)
    title('Lente sin filtrar')
    shading interp
    qOriginal= filtra_q(qOriginal,0,0);

end
   